@@ -9,20 +9,20 @@
 # lost the next time ruby is built.
 
 module RbConfig
-  RUBY_VERSION.start_with?("3.0.") or
-    raise "ruby lib version (3.0.6) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION.start_with?("3.2.") or
+    raise "ruby lib version (3.2.4) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
-  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.0.0/armv7l-linux-eabihf")
+  TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.2.0/armv7l-linux-eabihf")
   # DESTDIR on make install.
   DESTDIR = '' unless defined? DESTDIR
   # The hash configurations stored.
   CONFIG = {}
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
-  CONFIG["MINOR"] = "0"
-  CONFIG["TEENY"] = "6"
-  CONFIG["PATCHLEVEL"] = "216"
+  CONFIG["MINOR"] = "2"
+  CONFIG["TEENY"] = "4"
+  CONFIG["PATCHLEVEL"] = "170"
   CONFIG["INSTALL"] = '/usr/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr")
@@ -30,10 +30,11 @@ module RbConfig
   CONFIG["RUBY_INSTALL_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["RUBY_SO_NAME"] = "$(RUBY_BASE_NAME)"
   CONFIG["exec"] = "exec"
-  CONFIG["ruby_pc"] = "ruby-3.0.pc"
+  CONFIG["ruby_pc"] = "ruby-3.2.pc"
   CONFIG["CC_WRAPPER"] = ""
   CONFIG["PACKAGE"] = "ruby"
   CONFIG["BUILTIN_TRANSSRCS"] = " enc/trans/newline.c"
+  CONFIG["MKMF_VERBOSE"] = "0"
   CONFIG["MANTYPE"] = "doc"
   CONFIG["vendorarchhdrdir"] = "$(vendorhdrdir)/$(sitearch)"
   CONFIG["sitearchhdrdir"] = "$(sitehdrdir)/$(sitearch)"
@@ -44,7 +45,7 @@ module RbConfig
   CONFIG["RUBY_SEARCH_PATH"] = ""
   CONFIG["UNIVERSAL_INTS"] = ""
   CONFIG["UNIVERSAL_ARCHNAMES"] = ""
-  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CXXFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=' 'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection'"
+  CONFIG["configure_args"] = " '--prefix=/usr' '--sysconfdir=/etc' '--localstatedir=/var' '--sharedstatedir=/var/lib' '--libexecdir=/usr/lib/ruby' '--enable-shared' '--disable-rpath' '--with-dbm-type=gdbm_compat' 'CFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wno-incompatible-pointer-types' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=' 'CXXFLAGS=-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Wno-incompatible-pointer-types'"
   CONFIG["CONFIGURE"] = "configure"
   CONFIG["vendorarchdir"] = "$(vendorlibdir)/$(sitearch)"
   CONFIG["vendorlibdir"] = "$(vendordir)/$(ruby_version)"
@@ -54,7 +55,7 @@ module RbConfig
   CONFIG["sitedir"] = "$(rubylibprefix)/site_ruby"
   CONFIG["rubyarchdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["rubylibdir"] = "$(rubylibprefix)/$(ruby_version)"
-  CONFIG["ruby_version"] = "3.0.0"
+  CONFIG["ruby_version"] = "3.2.0"
   CONFIG["sitearch"] = "$(arch)"
   CONFIG["arch"] = "armv7l-linux-eabihf"
   CONFIG["sitearchincludedir"] = "$(includedir)/$(sitearch)"
@@ -71,16 +72,17 @@ module RbConfig
   CONFIG["rubyarchprefix"] = "$(rubylibprefix)/$(arch)"
   CONFIG["MAKEFILES"] = "Makefile GNUmakefile"
   CONFIG["PLATFORM_DIR"] = ""
+  CONFIG["COROUTINE_TYPE"] = "arm32"
   CONFIG["THREAD_MODEL"] = "pthread"
   CONFIG["SYMBOL_PREFIX"] = ""
   CONFIG["EXPORT_PREFIX"] = ""
   CONFIG["COMMON_HEADERS"] = ""
   CONFIG["COMMON_MACROS"] = ""
   CONFIG["COMMON_LIBS"] = ""
-  CONFIG["MAINLIBS"] = "-lz -lpthread -lrt -lrt -lgmp -ldl -lcrypt -lm "
+  CONFIG["MAINLIBS"] = "-lz -lrt -lrt -lgmp -ldl -lcrypt -lm -lpthread "
   CONFIG["ENABLE_SHARED"] = "yes"
   CONFIG["DLDSHARED"] = "$(CC) -shared"
-  CONFIG["DLDLIBS"] = " -lc"
+  CONFIG["DLDLIBS"] = "-lc"
   CONFIG["SOLIBS"] = "$(MAINLIBS)"
   CONFIG["LIBRUBYARG_SHARED"] = "-l$(RUBY_SO_NAME)"
   CONFIG["LIBRUBYARG_STATIC"] = "-l$(RUBY_SO_NAME)-static $(MAINLIBS)"
@@ -94,14 +96,20 @@ module RbConfig
   CONFIG["rubyw_install_name"] = ""
   CONFIG["EXTDLDFLAGS"] = ""
   CONFIG["EXTLDFLAGS"] = ""
-  CONFIG["strict_warnflags"] = "-std=gnu99"
-  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wwrite-strings -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable"
+  CONFIG["strict_warnflags"] = ""
+  CONFIG["warnflags"] = "-Wall -Wextra -Wdeprecated-declarations -Wdiv-by-zero -Wduplicated-cond -Wimplicit-function-declaration -Wimplicit-int -Wmisleading-indentation -Wpointer-arith -Wwrite-strings -Wold-style-definition -Wimplicit-fallthrough=0 -Wmissing-noreturn -Wno-cast-function-type -Wno-constant-logical-operand -Wno-long-long -Wno-missing-field-initializers -Wno-overlength-strings -Wno-packed-bitfield-compat -Wno-parentheses-equality -Wno-self-assign -Wno-tautological-compare -Wno-unused-parameter -Wno-unused-value -Wsuggest-attribute=format -Wsuggest-attribute=noreturn -Wunused-variable -Wundef"
   CONFIG["debugflags"] = "-ggdb3"
-  CONFIG["optflags"] = "-O3"
+  CONFIG["optflags"] = "-O3 -fno-fast-math"
   CONFIG["NULLCMD"] = ":"
   CONFIG["ENABLE_DEBUG_ENV"] = ""
   CONFIG["DLNOBJ"] = "dln.o"
   CONFIG["INSTALL_STATIC_LIBRARY"] = "no"
+  CONFIG["YJIT_OBJ"] = ""
+  CONFIG["YJIT_LIBS"] = ""
+  CONFIG["CARGO_BUILD_ARGS"] = ""
+  CONFIG["YJIT_SUPPORT"] = "no"
+  CONFIG["CARGO"] = ""
+  CONFIG["RUSTC"] = "rustc"
   CONFIG["MJIT_SUPPORT"] = "yes"
   CONFIG["EXECUTABLE_EXTS"] = ""
   CONFIG["ARCHFILE"] = ""
@@ -112,8 +120,6 @@ module RbConfig
   CONFIG["TEST_RUNNABLE"] = "yes"
   CONFIG["rubylibprefix"] = "$(libdir)/$(RUBY_BASE_NAME)"
   CONFIG["setup"] = "Setup"
-  CONFIG["ENCSTATIC"] = ""
-  CONFIG["EXTSTATIC"] = ""
   CONFIG["SOEXT"] = "so"
   CONFIG["TRY_LINK"] = ""
   CONFIG["PRELOADENV"] = "LD_PRELOAD"
@@ -122,9 +128,10 @@ module RbConfig
   CONFIG["LIBPATHFLAG"] = " -L%s"
   CONFIG["LINK_SO"] = ""
   CONFIG["ADDITIONAL_DLDFLAGS"] = ""
+  CONFIG["ENCSTATIC"] = ""
+  CONFIG["EXTSTATIC"] = ""
   CONFIG["ASMEXT"] = "S"
   CONFIG["LIBEXT"] = "a"
-  CONFIG["DLEXT2"] = ""
   CONFIG["DLEXT"] = "so"
   CONFIG["LDSHAREDXX"] = "$(CXX) -shared"
   CONFIG["LDSHARED"] = "$(CC) -shared"
@@ -137,8 +144,10 @@ module RbConfig
   CONFIG["GREP"] = "/usr/bin/grep"
   CONFIG["dsymutil"] = ""
   CONFIG["codesign"] = ""
+  CONFIG["cleanlibs"] = ""
   CONFIG["POSTLINK"] = ":"
   CONFIG["WERRORFLAG"] = "-Werror"
+  CONFIG["RUBY_DEVEL"] = ""
   CONFIG["CHDIR"] = "cd -P"
   CONFIG["RMALL"] = "rm -fr"
   CONFIG["RMDIRS"] = "rmdir --ignore-fail-on-non-empty -p"
@@ -148,7 +157,6 @@ module RbConfig
   CONFIG["PKG_CONFIG"] = "pkg-config"
   CONFIG["DOXYGEN"] = "doxygen"
   CONFIG["DOT"] = "dot"
-  CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["MKDIR_P"] = "/usr/bin/mkdir -p"
   CONFIG["INSTALL_DATA"] = "$(INSTALL) -m 644"
   CONFIG["INSTALL_SCRIPT"] = "$(INSTALL)"
@@ -160,7 +168,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "armv7l-unknown-linux-gnueabihf-gcc (GCC) 12.1.0\nCopyright (C) 2022 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
+  CONFIG["CC_VERSION_MESSAGE"] = "armv7l-unknown-linux-gnueabihf-gcc (GCC) 14.1.1 20240507\nCopyright (C) 2024 Free Software Foundation, Inc.\nThis is free software; see the source for copying conditions.  There is NO\nwarranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE."
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/lib/distcc/bin/gcc"
   CONFIG["CSRCFLAG"] = ""
@@ -170,11 +178,11 @@ module RbConfig
   CONFIG["GNU_LD"] = "yes"
   CONFIG["GCC"] = "yes"
   CONFIG["CPP"] = "$(CC) -E"
-  CONFIG["CFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -fPIC"
+  CONFIG["CXXFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS -Wno-incompatible-pointer-types"
   CONFIG["OBJEXT"] = "o"
   CONFIG["CPPFLAGS"] = " $(DEFS) $(cppflags)"
   CONFIG["LDFLAGS"] = "-L. -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now -fstack-protector-strong -rdynamic -Wl,-export-dynamic -Wl,--no-as-needed"
-  CONFIG["CXXFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wp,-D_GLIBCXX_ASSERTIONS"
+  CONFIG["CFLAGS"] = "-march=armv7-a -mfloat-abi=hard -mfpu=neon -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection -Wno-incompatible-pointer-types -fPIC"
   CONFIG["STRIP"] = "strip -S -x"
   CONFIG["RANLIB"] = "gcc-ranlib"
   CONFIG["OBJDUMP"] = "objdump"
@@ -185,14 +193,16 @@ module RbConfig
   CONFIG["AS"] = "as"
   CONFIG["AR"] = "gcc-ar"
   CONFIG["CC"] = "gcc"
+  CONFIG["wasmoptflags"] = ""
+  CONFIG["WASMOPT"] = ""
   CONFIG["target_os"] = "linux-eabihf"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "armv7l"
-  CONFIG["target"] = "armv7l-unknown-linux-gnueabihf"
-  CONFIG["host_os"] = "linux-eabihf"
-  CONFIG["host_vendor"] = "unknown"
-  CONFIG["host_cpu"] = "armv7l"
-  CONFIG["host"] = "armv7l-unknown-linux-gnueabihf"
+  CONFIG["target"] = "$(target_cpu)-$(target_vendor)-$(target_os)"
+  CONFIG["host_os"] = "$(target_os)"
+  CONFIG["host_vendor"] = "$(target_vendor)"
+  CONFIG["host_cpu"] = "$(target_cpu)"
+  CONFIG["host"] = "$(target)"
   CONFIG["build_os"] = "linux-gnueabihf"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "armv7l"
@@ -207,10 +217,11 @@ module RbConfig
   CONFIG["cxxflags"] = ""
   CONFIG["cppflags"] = ""
   CONFIG["cflags"] = "$(optflags) $(debugflags) $(warnflags)"
+  CONFIG["MAKEDIRS"] = "/usr/bin/mkdir -p"
   CONFIG["target_alias"] = ""
-  CONFIG["host_alias"] = ""
+  CONFIG["host_alias"] = "$(target_alias)"
   CONFIG["build_alias"] = ""
-  CONFIG["LIBS"] = "-lm "
+  CONFIG["LIBS"] = "-lm -lpthread "
   CONFIG["ECHO_T"] = ""
   CONFIG["ECHO_N"] = "-n"
   CONFIG["ECHO_C"] = ""
@@ -244,8 +255,9 @@ module RbConfig
   CONFIG["PACKAGE_NAME"] = ""
   CONFIG["PATH_SEPARATOR"] = ":"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["UNICODE_VERSION"] = "12.1.0"
-  CONFIG["UNICODE_EMOJI_VERSION"] = "12.1"
+  CONFIG["UNICODE_VERSION"] = "15.0.0"
+  CONFIG["UNICODE_EMOJI_VERSION"] = "15.0"
+  CONFIG["platform"] = "$(arch)"
   CONFIG["archdir"] = "$(rubyarchdir)"
   CONFIG["topdir"] = File.dirname(__FILE__)
   # Almost same with CONFIG. MAKEFILE_CONFIG has other variable
@@ -305,7 +317,6 @@ module RbConfig
     RbConfig::expand(val)
   end
 
-  # :nodoc:
   # call-seq:
   #
   #   RbConfig.fire_update!(key, val)               -> array
@@ -321,7 +332,7 @@ module RbConfig
   #   RbConfig::CONFIG.values_at("CC", "LDSHARED")          # => ["gcc-8", "gcc-8 -shared"]
   #
   # returns updated keys list, or +nil+ if nothing changed.
-  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG)
+  def RbConfig.fire_update!(key, val, mkconf = MAKEFILE_CONFIG, conf = CONFIG) # :nodoc:
     return if mkconf[key] == val
     mkconf[key] = val
     keys = [key]
